@@ -59,11 +59,19 @@
 #' @inheritParams tidy_select_variables
 #' @param keep_model should the model be kept as an attribute of the final
 #' result?
+#' @param tidy_post_fun custom function applied to the results at the end of
+#' `tidy_plus_plus()` (see note)
 #' @param quiet logical argument whether broom.helpers should not return
 #' a message when requested output cannot be generated. Default is `FALSE`
 #' @param strict logical argument whether broom.helpers should return an error
 #' when requested output cannot be generated. Default is `FALSE`
 #' @param ... other arguments passed to `tidy_fun()`
+#' @note
+#' `tidy_post_fun` is applied to the result at the end of `tidy_plus_plus()`
+#' and receive only one argument (the result of `tidy_plus_plus()`). However,
+#' if needed, the model is still attached to the tibble as an attribute, even
+#' if `keep_model = FALSE`. Therefore, it is possible to use [tidy_get_model()]
+#' within `tidy_fun` if, for any reason, you need to access the source model.
 #' @family tidy_helpers
 #' @examplesIf interactive()
 #' ex1 <- lm(Sepal.Length ~ Sepal.Width + Species, data = iris) %>%
@@ -79,18 +87,18 @@
 #'     Class = "Passenger's class",
 #'     Sex = "Gender"
 #'   )
-#'   ex2 <- glm(
-#'     Survived ~ Class + Age * Sex,
-#'     data = df, weights = df$n,
-#'     family = binomial
-#'   ) %>%
-#'     tidy_plus_plus(
-#'       exponentiate = TRUE,
-#'       add_reference_rows = FALSE,
-#'       categorical_terms_pattern = "{level} / {reference_level}",
-#'       add_n = TRUE
-#'     )
-#'   ex2
+#' ex2 <- glm(
+#'   Survived ~ Class + Age * Sex,
+#'   data = df, weights = df$n,
+#'   family = binomial
+#' ) %>%
+#'   tidy_plus_plus(
+#'     exponentiate = TRUE,
+#'     add_reference_rows = FALSE,
+#'     categorical_terms_pattern = "{level} / {reference_level}",
+#'     add_n = TRUE
+#'   )
+#' ex2
 #' if (.assert_package("gtsummary", boolean = TRUE)) {
 #'   ex3 <-
 #'     glm(
@@ -113,8 +121,7 @@
 #'   ex3
 #' }
 #' @export
-tidy_plus_plus <- function(
-                           model,
+tidy_plus_plus <- function(model,
                            tidy_fun = tidy_with_broom_or_parameters,
                            conf.int = TRUE,
                            conf.level = .95,
@@ -140,6 +147,7 @@ tidy_plus_plus <- function(
                            intercept = FALSE,
                            include = everything(),
                            keep_model = FALSE,
+                           tidy_post_fun = NULL,
                            quiet = FALSE,
                            strict = FALSE,
                            ...) {
@@ -189,7 +197,7 @@ tidy_plus_plus <- function(
       labels = variable_labels,
       interaction_sep = interaction_sep,
       quiet = quiet
-      ) %>%
+    ) %>%
     tidy_add_term_labels(
       labels = term_labels,
       interaction_sep = interaction_sep,
@@ -199,8 +207,10 @@ tidy_plus_plus <- function(
 
   if (add_header_rows) {
     res <- res %>%
-      tidy_add_header_rows(show_single_row = {{ show_single_row }},
-                           strict = strict, quiet = quiet)
+      tidy_add_header_rows(
+        show_single_row = {{ show_single_row }},
+        strict = strict, quiet = quiet
+      )
   }
 
   if (add_n) {
@@ -217,6 +227,9 @@ tidy_plus_plus <- function(
     ) %>%
     tidy_add_coefficients_type()
 
+  if (!is.null(tidy_post_fun))
+    res <- res %>% tidy_post_fun()
+
   if (!keep_model) {
     res <- res %>% tidy_detach_model()
   }
